#! /usr/bin/python
# -*- coding: iso-8859-1 -*-
#
__author__='atareao'
__date__ ='$09/07/2011'
#
#
# Copyright (C) 2010 Lorenzo Carbonell
# lorenzo.carbonell.cerezo@gmail.com
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#
#

#install gir1.2-gnomekeyring-1.0
from gi.repository import GnomeKeyring, GLib
import ConfigParser
import os

APP = 'google-reader-indicator'
APP_CONF = APP + '.conf'
'''
PARAMS = {	'user':{ 'value':'','default':''},
			'refresh_time':{ 'value':'','default':'5'},
			'theme':{ 'value':'','default':'dark'}
			}
'''
PARAMS = {	'user':{ 'value':'','default':''}}

config_dir = os.path.join(os.path.expanduser('~'),'.config')
config_app_dir = os.path.join(config_dir, APP)
config_file = os.path.join(config_app_dir, APP_CONF)



class Configuration(object):
	
	def __init__(self):
		self.params = PARAMS
		self.config = ConfigParser.RawConfigParser()
		if not os.path.exists(config_file):
			self.create()
			self.save()
		self.read()
		self.keyring = self.get_value('keyring')
		self.password = self.get_password()
		#
		self.read_params()
	
	def get(self,key):
		if key == 'password':
			return self.password
		value = self.params[key]['value']
		if value == None or value == '':
			value = self.params[key]['default']
			self.params[key]['value'] = value
		return value

	def set(self,key,value):
		if key == 'password':
			self.password = value
		else:
			if value == None or value == '':
				value = self.params[key]['default']
			self.params[key]['value'] = value
			
	def read_params(self):
		for key in self.params.keys():
			value = self.get_value(key)
			if value == None or value == '':
				value = self.params[key]['default']
			self.params[key]['value'] = value
	
	def save_params(self):
		for key in self.params.keys():
			value = self.params[key]['value']
			if value == None or value == '':
				value = self.params[key]['default']
			self.config.set('Configuration', key, value)
			
	def _get_default_keyring_name(self):
		return GnomeKeyring.get_default_keyring_sync()[1]

	def _get_item(self, keyring, name):
		for id in GnomeKeyring.list_item_ids_sync(keyring)[1]:
			item = GnomeKeyring.item_get_info_sync(keyring, id)[1]
			if item.get_display_name() == name:
				return id,item
		return None

	def _set_password(self, keyring, name, password):
		item = self._get_item(keyring, name)
		if item:
			id,item = item
			info = GnomeKeyring.item_get_info_sync(keyring, id)[1]
			info.set_secret(password)
			GnomeKeyring.item_set_info_sync(keyring,id, info)
		else:
			GnomeKeyring.item_create_sync(keyring, GnomeKeyring.ItemType.GENERIC_SECRET, name, GLib.Array(), password, False)	

	def _get_password(self, keyring, name):
		for id in GnomeKeyring.list_item_ids_sync(keyring)[1]:
			item = GnomeKeyring.item_get_info_sync(keyring, id)[1]
			if item.get_display_name() == name:
				return item.get_secret()
		return None

	def read(self):
		 self.config.read(config_file)
	
	def get_value(self,key):
		try:
			value = self.config.get('Configuration', key)
		except Exception,e:
			print e
			value = None
		if value == 'None':
			value = None
		return value
	
	def get_password(self):
		return self._get_password(self.keyring,APP)

	def create(self):
		if not self.config.has_section('Configuration'):
			self.config.add_section('Configuration')
		self.set_defaults()
	
	def set_defaults(self):
		self.password = ''		
		self.keyring = self._get_default_keyring_name()
		for key in self.params.keys():
			value = self.get_value(key)
			if value == None or value == '':
				value = self.params[key]['default']
				self.params[key]['value'] = value

	def save(self):
		self.config.set('Configuration', 'keyring', self.keyring)
		self.save_params()
		if not os.path.exists(config_app_dir):
			os.makedirs(config_app_dir)
		self.config.write(open(config_file, 'w'))
		self._set_password(self.keyring, APP, self.password)

if __name__=='__main__':
	configuration = Configuration()
	print 'refresh_time %s'%configuration.get('refresh_time')
	#configuration.password = 'tteesfffaa'
	configuration.set('refresh_time','5')
	configuration.save()
	print configuration.get_password()
